ByteAccumulatorSink class

A sink that provides access to the concatenated bytes passed to it.

See also ByteConversionSink.withCallback.

Inheritance

Constructors

ByteAccumulatorSink()

Properties

bytes → Uint8List
The bytes accumulated so far.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether close has been called.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> chunk) → void
Adds chunked data to this sink.
override
addSlice(List<int> chunk, int start, int end, bool isLast) → void
Adds the next chunk to this.
override
clear() → void
Removes all bytes from bytes.
close() → void
Closes the sink.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited