HexCodec class

A codec that converts byte arrays to and from hexadecimal strings, following the Base16 spec.

This should be used via the hex field.

Inheritance

Properties

decoder → HexDecoder
Returns the decoder of this, converting from T to S.
no setteroverride
encoder → HexEncoder
Returns the encoder from S to T.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inverted → Codec<String, List<int>>
Inverts this.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String encoded) → List<int>
Decodes encoded data.
inherited
encode(List<int> input) → String
Encodes input.
inherited
fuse<R>(Codec<String, R> other) → Codec<List<int>, R>
Fuses this with other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited