StringAccumulatorSink class

A sink that provides access to the concatenated strings passed to it.

See also StringConversionSink.withCallback.

Inheritance

Constructors

StringAccumulatorSink()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isClosed → bool
Whether close has been called.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → String
The string accumulated so far.
no setter

Methods

add(String str) → void
Adds chunked data to this sink.
override
addSlice(String chunk, int start, int end, bool isLast) → void
Adds the next chunk to this.
override
asStringSink() → ClosableStringSink
Returns this as a ClosableStringSink.
inherited
asUtf8Sink(bool allowMalformed) → ByteConversionSink
Returns this as a sink that accepts UTF-8 input.
inherited
clear() → void
Empties string.
close() → void
Closes the sink.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited